@@ -139,7 +139,7 @@ impl<P: Sync + Send + Serialize + DeserializeOwned> Checkout<P> {
     async fn enter_payment_in_progress_state<C: Context + Send>(
         &mut self,
         ctx: &mut C,
-        args: <C as PaymentProcessor>::ProcessArgs,
+        args: <C as PaymentProcessor>::InitArgs,
         deadline: DateTime<Utc>,
     ) -> Result<(), Error> {
         let charge_amount = self.invoice.as_ref().unwrap().initial_charge_amount.clone();
@@ -185,7 +185,7 @@ impl<P: Sync + Send + Serialize + DeserializeOwned> Checkout<P> {
     async fn ensure_payment_in_progress_state<C: Context + Send>(
         &mut self,
         ctx: &mut C,
-        args: <C as PaymentProcessor>::ProcessArgs,
+        args: <C as PaymentProcessor>::InitArgs,
     ) -> Result<(), Error> {
         match self.state {
             State::PaymentInProgress(_) => Ok(()),
@@ -431,7 +431,7 @@ impl<P: Sync + Send + Serialize + DeserializeOwned> Checkout<P> {
     pub async fn initiate_payment<C: Context + Send>(
         &mut self,
         ctx: &mut C,
-        args: <C as PaymentProcessor>::ProcessArgs,
+        args: <C as PaymentProcessor>::InitArgs,
     ) -> Result<(), Error> {
         self.ensure_payment_in_progress_state(ctx, args).await?;
 
@@ -442,7 +442,7 @@ impl<P: Sync + Send + Serialize + DeserializeOwned> Checkout<P> {
         &mut self,
         internal_ctx: &InternalContext,
         ctx: &mut C,
-        payment_args: <C as PaymentProcessor>::ProcessArgs,
+        payment_args: <C as PaymentProcessor>::InitArgs,
     ) -> Result<(), Error> {
         if !matches!(self.state, State::ItemsConfirmed(_)) {
             return Err(new_invalid_state_error(
