@@ -152,7 +152,7 @@ impl<P: Sync + Send + Serialize + DeserializeOwned> Order<P> {
         internal_ctx: &InternalContext,
         ctx: &mut C,
         checkout: &Checkout<P>,
-        payment_args: <C as PaymentProcessor>::ProcessArgs,
+        payment_args: <C as PaymentProcessor>::InitArgs,
     ) -> Result<Self, Error> {
         let mut order = Order {
             id: Uuid::new_v4().to_string(),
