@@ -63,12 +63,13 @@ impl<T: DeserializeOwned> cloud_pubsub::FromPubSubMessage for CallbackArgs<T> {
 #[async_trait]
 pub trait PaymentProcessor {
     type Data: Sync + Send + Serialize + DeserializeOwned;
+    type InitArgs: Sync + Send + Serialize + DeserializeOwned;
     type ProcessArgs: Sync + Send + Serialize + DeserializeOwned;
 
     async fn initiate_payment(
         &mut self,
         _payment: &Payment<Self::Data>,
-        _args: &Self::ProcessArgs,
+        _args: &Self::InitArgs,
     ) -> Result<PaymentData<Self::Data>, Error> {
         Ok(PaymentData {
             correlation_id: None,
@@ -141,7 +142,7 @@ async fn new<'a, C: Context + Send, P: Sync + Send + Serialize + DeserializeOwne
     ctx: &mut C,
     initiator: Initiator<'a, P>,
     charge_amount: Money,
-    args: <C as PaymentProcessor>::ProcessArgs,
+    args: <C as PaymentProcessor>::InitArgs,
 ) -> Result<Payment<<C as PaymentProcessor>::Data>, Error> {
     let mut payment = Payment {
         id: Uuid::new_v4().to_string(),
